@@ -20,18 +20,18 @@
 #define GLOBAL_INTERFACE_KEY "/desktop/gnome/interface"
 
 static GConfEnumStringPair toolbar_styles[] = {
-        { BONOBO_UI_TOOLBAR_STYLE_TEXT_ONLY,      "text" },
-        { BONOBO_UI_TOOLBAR_STYLE_ICONS_ONLY,     "icons" },
-        { BONOBO_UI_TOOLBAR_STYLE_ICONS_AND_TEXT, "both" },
-        { BONOBO_UI_TOOLBAR_STYLE_PRIORITY_TEXT,  "both_horiz" },
-	{ BONOBO_UI_TOOLBAR_STYLE_PRIORITY_TEXT,  "both-horiz" },
+        { GTK_TOOLBAR_TEXT,        "text" },
+        { GTK_TOOLBAR_ICONS,       "icons" },
+        { GTK_TOOLBAR_BOTH,        "both" },
+        { GTK_TOOLBAR_BOTH_HORIZ,  "both_horiz" },
+	{ GTK_TOOLBAR_BOTH_HORIZ,  "both-horiz" },
 	{ -1, NULL }
 };
 
 static GConfClient *client;
 static GSList *engine_list;
-guint desktop_notify_id;
-guint update_engines_idle_id;
+static guint desktop_notify_id;
+static guint update_engines_idle_id;
 
 static void keys_changed_fn (GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data);
 
@@ -161,25 +161,29 @@ bonobo_ui_preferences_get_toolbar_style (void)
 	if (!client)
 		client = gconf_client_get_default ();
 
-	style = BONOBO_UI_TOOLBAR_STYLE_ICONS_AND_TEXT;
+	style = GTK_TOOLBAR_BOTH;
 
 	str = gconf_client_get_string (client,
 				       "/desktop/gnome/interface/toolbar_style",
 				       NULL);
 	
 	if (str != NULL) {
+		gint intstyle;
+
 		gconf_string_to_enum (toolbar_styles,
-				      str, (gint *)&style);
+				      str, &intstyle);
+
 		g_free (str);
+		style = intstyle;
 	}
 
 	return style;
 }
 
-DEFINE_BONOBO_UI_PREFERENCE (toolbar_detachable, "toolbar_detachable", TRUE);
-DEFINE_BONOBO_UI_PREFERENCE (menus_have_icons,   "menus_have_icons",   TRUE);
-DEFINE_BONOBO_UI_PREFERENCE (menus_have_tearoff, "menus_have_tearoff", FALSE);
-DEFINE_BONOBO_UI_PREFERENCE (menubar_detachable, "menubar_detachable", TRUE);
+DEFINE_BONOBO_UI_PREFERENCE (toolbar_detachable, "toolbar_detachable", TRUE)
+DEFINE_BONOBO_UI_PREFERENCE (menus_have_icons,   "menus_have_icons",   TRUE)
+DEFINE_BONOBO_UI_PREFERENCE (menus_have_tearoff, "menus_have_tearoff", FALSE)
+DEFINE_BONOBO_UI_PREFERENCE (menubar_detachable, "menubar_detachable", TRUE)
 
 
 static void
@@ -203,5 +207,5 @@ keys_changed_fn (GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer
 	if (update_engines_idle_id != 0)
 		return;
 
-	update_engines_idle_id = gtk_idle_add (update_engines_idle_callback, NULL);
+	update_engines_idle_id = g_idle_add (update_engines_idle_callback, NULL);
 }
